pub struct VisualBell { /* private fields */ }Implementations
Sourceimpl VisualBell
impl VisualBell
pub fn new<C>(config: &Config<C>) -> VisualBell
Sourcepub fn intensity(&self) -> f64
pub fn intensity(&self) -> f64
Get the currently intensity of the visual bell. The bell’s intensity ramps down from 1.0 to 0.0 at a rate determined by the bell’s duration.
Sourcepub fn completed(&mut self) -> bool
pub fn completed(&mut self) -> bool
Check whether or not the visual bell has completed “ringing”.
Sourcepub fn intensity_at_instant(&self, instant: Instant) -> f64
pub fn intensity_at_instant(&self, instant: Instant) -> f64
Get the intensity of the visual bell at a particular instant. The bell’s intensity ramps down from 1.0 to 0.0 at a rate determined by the bell’s duration.
pub fn update_config<C>(&mut self, config: &Config<C>)